# Examples
In this directory is a simple `package_a` Python *literary* package, implemented using Jupyter Notebooks.

Most of the interesting example code is written inside `package_a`, where there a several notebooks covering each of the interesting Literary features.

## What \[is Literary\]?
Literary is a Python tool to make Jupyter (IPython) notebooks behave like pure-Python packages. This allows pure-Python packages to be generated from notebooks, and notebooks to be imported at runtime.

## Why?
I have written a small [wiki entry](https://github.com/agoose77/literary/wiki/Why%3F) that details my reasons for needing `literary`:
> Putting the tests, examples, and code all in one place, with support for Markdown rendering and visualisations vastly improved the legibility and reproducibility of my code.

